--- old/usr/src/uts/common/inet/tcp/tcp_stats.c	2015-12-04 14:19:25.625339899 +0300
+++ new/usr/src/uts/common/inet/tcp/tcp_stats.c	2015-12-04 14:19:25.633202132 +0300
@@ -30,6 +30,13 @@
 #include <sys/tsol/tnet.h>
 #include <sys/kstat.h>
 
+#include <sys/strsun.h>
+#include <sys/stropts.h>
+#include <sys/strsubr.h>
+#include <sys/socket.h>
+#include <sys/socketvar.h>
+#include <sys/uio.h>
+
 #include <inet/common.h>
 #include <inet/ip.h>
 #include <inet/tcp.h>
@@ -97,10 +104,14 @@
 	mblk_t			*mp_conn_tail;
 	mblk_t			*mp_attr_ctl = NULL;
 	mblk_t			*mp_attr_tail;
+	mblk_t			*mp_pidnode_ctl = NULL;
+	mblk_t			*mp_pidnode_tail;
 	mblk_t			*mp6_conn_ctl = NULL;
 	mblk_t			*mp6_conn_tail;
 	mblk_t			*mp6_attr_ctl = NULL;
 	mblk_t			*mp6_attr_tail;
+	mblk_t			*mp6_pidnode_ctl = NULL;
+	mblk_t			*mp6_pidnode_tail;
 	struct opthdr		*optp;
 	mib2_tcpConnEntry_t	tce;
 	mib2_tcp6ConnEntry_t	tce6;
@@ -127,12 +138,16 @@
 	    (mpdata = mpctl->b_cont) == NULL ||
 	    (mp_conn_ctl = copymsg(mpctl)) == NULL ||
 	    (mp_attr_ctl = copymsg(mpctl)) == NULL ||
+	    (mp_pidnode_ctl = copymsg(mpctl)) == NULL ||
 	    (mp6_conn_ctl = copymsg(mpctl)) == NULL ||
-	    (mp6_attr_ctl = copymsg(mpctl)) == NULL) {
+	    (mp6_attr_ctl = copymsg(mpctl)) == NULL ||
+	    (mp6_pidnode_ctl = copymsg(mpctl)) == NULL) {
 		freemsg(mp_conn_ctl);
 		freemsg(mp_attr_ctl);
+		freemsg(mp_pidnode_ctl);
 		freemsg(mp6_conn_ctl);
 		freemsg(mp6_attr_ctl);
+		freemsg(mp6_pidnode_ctl);
 		freemsg(mpctl);
 		freemsg(mp2ctl);
 		return (NULL);
@@ -166,6 +181,7 @@
 
 	v4_conn_idx = v6_conn_idx = 0;
 	mp_conn_tail = mp_attr_tail = mp6_conn_tail = mp6_attr_tail = NULL;
+	mp_pidnode_tail = mp6_pidnode_tail = NULL;
 
 	for (i = 0; i < CONN_G_HASH_SIZE; i++) {
 		ipst = tcps->tcps_netstack->netstack_ip;
@@ -281,6 +297,12 @@
 			(void) snmp_append_data2(mp6_conn_ctl->b_cont,
 			    &mp6_conn_tail, (char *)&tce6, tce6_size);
 
+			(void) snmp_append_data2(mp6_pidnode_ctl->b_cont,
+			    &mp6_pidnode_tail, (char *)&tce6, tce6_size);
+
+			(void) snmp_append_mblk2(mp6_pidnode_ctl->b_cont,
+			    &mp6_pidnode_tail, conn_get_pid_mblk(connp));
+
 			mlp.tme_connidx = v6_conn_idx++;
 			if (needattr)
 				(void) snmp_append_data2(mp6_attr_ctl->b_cont,
@@ -348,6 +370,12 @@
 				(void) snmp_append_data2(mp_conn_ctl->b_cont,
 				    &mp_conn_tail, (char *)&tce, tce_size);
 
+				(void) snmp_append_data2(mp_pidnode_ctl->b_cont,
+				    &mp_pidnode_tail, (char *)&tce, tce_size);
+
+				(void) snmp_append_mblk2(mp_pidnode_ctl->b_cont,
+				    &mp_pidnode_tail, conn_get_pid_mblk(connp));
+
 				mlp.tme_connidx = v4_conn_idx++;
 				if (needattr)
 					(void) snmp_append_data2(
@@ -417,6 +445,29 @@
 		freemsg(mp6_attr_ctl);
 	else
 		qreply(q, mp6_attr_ctl);
+
+	/* table of EXPER_XPORT_PROC_INFO  ipv4 */
+	optp = (struct opthdr *)&mp_pidnode_ctl->b_rptr[
+	    sizeof (struct T_optmgmt_ack)];
+	optp->level = MIB2_TCP;
+	optp->name = EXPER_XPORT_PROC_INFO;
+	optp->len = msgdsize(mp_pidnode_ctl->b_cont);
+	if (optp->len == 0)
+		freemsg(mp_pidnode_ctl);
+	else
+		qreply(q, mp_pidnode_ctl);
+
+	/* table of EXPER_XPORT_PROC_INFO  ipv6 */
+	optp = (struct opthdr *)&mp6_pidnode_ctl->b_rptr[
+	    sizeof (struct T_optmgmt_ack)];
+	optp->level = MIB2_TCP6;
+	optp->name = EXPER_XPORT_PROC_INFO;
+	optp->len = msgdsize(mp6_pidnode_ctl->b_cont);
+	if (optp->len == 0)
+		freemsg(mp6_pidnode_ctl);
+	else
+		qreply(q, mp6_pidnode_ctl);
+
 	return (mp2ctl);
 }
 
